from setuptools import setup

setup(name='django-coffee',
      version='0.0.4',
      description='Django Coffee',
      url='https://github.com/jacothiart/django-coffee',
      author='Jaco Thiart',
      author_email='jaco@jacothiart.com',
      license='MIT',
      packages=['coffee'],
      zip_safe=False)
